package com.bonus.material.ma.mapper;

import java.util.List;
import com.bonus.material.ma.domain.WholeSet;

/**
 * 成套设备Mapper接口
 * 
 * @author xsheng
 * @date 2024-09-27
 */
public interface WholeSetMapper 
{
    /**
     * 查询成套设备
     * 
     * @param id 成套设备主键
     * @return 成套设备
     */
    public WholeSet selectWholeSetById(Long id);

    /**
     * 查询成套设备列表
     * 
     * @param wholeSet 成套设备
     * @return 成套设备集合
     */
    public List<WholeSet> selectWholeSetList(WholeSet wholeSet);

    /**
     * 新增成套设备
     * 
     * @param wholeSet 成套设备
     * @return 结果
     */
    public int insertWholeSet(WholeSet wholeSet);

    /**
     * 修改成套设备
     * 
     * @param wholeSet 成套设备
     * @return 结果
     */
    public int updateWholeSet(WholeSet wholeSet);

    /**
     * 删除成套设备
     * 
     * @param id 成套设备主键
     * @return 结果
     */
    public int deleteWholeSetById(Long id);

    /**
     * 批量删除成套设备
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteWholeSetByIds(Long[] ids);
}
