package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.WholeSet;
import com.bonus.material.ma.service.IWholeSetService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 成套设备Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "成套设备接口")
@RestController
@RequestMapping("/ma_whole_set")
public class WholeSetController extends BaseController
{
    @Autowired
    private IWholeSetService wholeSetService;

    /**
     * 查询成套设备列表
     */
    @ApiOperation(value = "查询成套设备列表")
    @RequiresPermissions("ma:set:list")
    @GetMapping("/list")
    public TableDataInfo list(WholeSet wholeSet)
    {
        startPage();
        List<WholeSet> list = wholeSetService.selectWholeSetList(wholeSet);
        return getDataTable(list);
    }

    /**
     * 导出成套设备列表
     */
    @ApiOperation(value = "导出成套设备列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:export")
    @SysLog(title = "成套设备", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出成套设备")
    @PostMapping("/export")
    public void export(HttpServletResponse response, WholeSet wholeSet)
    {
        List<WholeSet> list = wholeSetService.selectWholeSetList(wholeSet);
        ExcelUtil<WholeSet> util = new ExcelUtil<WholeSet>(WholeSet.class);
        util.exportExcel(response, list, "成套设备数据");
    }

    /**
     * 获取成套设备详细信息
     */
    @ApiOperation(value = "获取成套设备详细信息")
    @RequiresPermissions("ma:set:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(wholeSetService.selectWholeSetById(id));
    }

    /**
     * 新增成套设备
     */
    @ApiOperation(value = "新增成套设备")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:add")
    @SysLog(title = "成套设备", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增成套设备")
    @PostMapping
    public AjaxResult add(@RequestBody WholeSet wholeSet)
    {
        return toAjax(wholeSetService.insertWholeSet(wholeSet));
    }

    /**
     * 修改成套设备
     */
    @ApiOperation(value = "修改成套设备")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:edit")
    @SysLog(title = "成套设备", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改成套设备")
    @PutMapping
    public AjaxResult edit(@RequestBody WholeSet wholeSet)
    {
        return toAjax(wholeSetService.updateWholeSet(wholeSet));
    }

    /**
     * 删除成套设备
     */
    @ApiOperation(value = "删除成套设备")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:set:remove")
    @SysLog(title = "成套设备", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除成套设备")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(wholeSetService.deleteWholeSetByIds(ids));
    }
}
